@@ -431,21 +431,17 @@ class MongoSubObjectBase(MongoParentAware, SetupConvertDump):
 
     # built in skip and dump names
     _skipNames = []
-    _dumpNames = ['_type', '__name__', 'created', 'modified']
-
-    # attrs with default values
-    created = MongoFieldProperty(interfaces.IMongoSubObject['created'])
-    modified = MongoFieldProperty(interfaces.IMongoSubObject['modified'])
+    _dumpNames = ['_type', '__name__']
 
     def __init__(self, data):
-        """Initialize a mongo item with given data.
+        """Initialize a mongo sub object with given data.
 
-        This method will also make sure that the __parent__ and other values
-        get set before we call setup.
+        This method will also make sure that the __name__ and __parent__ and
+        other values get set before we call setup.
 
-        Note: if you enhance your own MongoItem __init__ method, don't forget
-        to set_m_changed to None. Otherwise it will end in write access on
-        each read.
+        Note: if you enhance your own MongoSubObjectBase __init__ method, don't
+        forget to set_m_changed to None if you change value. Otherwise it will
+        end in write access on each read access.
         """
         # set given or None __name__ and __parent__
         self.__name__ = data.pop('__name__', None)
@@ -456,11 +452,6 @@ class MongoSubObjectBase(MongoParentAware, SetupConvertDump):
             if _type != self.__class__.__name__:
                 raise TypeError("Wrong mongo item _type used")
             self.__dict__['_type'] = unicode(_type)
-        # set given or new created datetime
-        created = data.pop('created', _marker)
-        if created is _marker:
-            created = datetime.datetime.now(UTC)
-        self.__dict__['created'] = created
         # setup object with given (non IMongoItem) key/value data
         self.setup(data)
         # it is very important to set _m_changed to None, otherwise each read
