@@ -12,7 +12,7 @@
 #
 ##############################################################################
 """A pymongo client with environment based setup
-$Id: client.py 4723 2018-02-04 08:42:19Z roger.ineichen $
+$Id: client.py 5071 2021-01-14 08:17:22Z roger.ineichen $
 """
 __docformat__ = "reStructuredText"
 
@@ -25,6 +25,10 @@ import pymongo
 
 client = None
 
+# TODO: implement all options defined in pymongo/common.py
+# TODO: support **kwargs and update options at the end for override existing
+#       or define undefined options given from new mongo versions
+
 def getMongoClient(settings=None, connect=True, retry=True):
     global client
     if client is not None:
@@ -34,8 +38,9 @@ def getMongoClient(settings=None, connect=True, retry=True):
     if settings is None:
         from m01.mongo import settings
     uri = settings.MONGODB_URI
-    if uri == 'testing' or settings.P01_CDN_RECIPE_PROCESS:
-        # testing or resource extraction, just a dumy client using testing port
+    if uri == 'testing' or settings.P01_CDN_RECIPE_PROCESS or \
+        settings.I18N_EXTRACT:
+        # testing or resource extraction, just a dummy client using testing port
         return pymongo.MongoClient('localhost:45017')
     else:
         uri = str(uri)
@@ -96,6 +101,8 @@ def getMongoClient(settings=None, connect=True, retry=True):
                 options['ssl_ca_certs'] = settings.MONGODB_CA_CERT
             if settings.MONGODB_CLIENT_CERT:
                 options['ssl_certfile'] = settings.MONGODB_CLIENT_CERT
+            if settings.MONGODB_CLIENT_CERT_KEY_FILE:
+                options['ssl_keyfile'] = settings.MONGODB_CLIENT_CERT_KEY_FILE
             if settings.MONGODB_PEM_PASSPHRASE:
                 options['ssl_pem_passphrase'] = settings.MONGODB_PEM_PASSPHRASE
             if settings.MONGODB_REVOCATION_LIST:
@@ -103,6 +110,28 @@ def getMongoClient(settings=None, connect=True, retry=True):
             if settings.MONGODB_SSL_MATCH_HOSTNAME:
                 options['ssl_match_hostname'] = \
                     settings.MONGODB_SSL_MATCH_HOSTNAME
+        # tls options
+        if settings.MONGODB_TLS:
+            options['tls'] = settings.MONGODB_TLS
+            if settings.MONGODB_TLS_CA_FILE:
+                options['tlsCAFile'] = settings.MONGODB_TLS_CA_FILE
+            if settings.MONGODB_TLS_CERT_KEY_FILE:
+                options['tlsCertificateKeyFile'] = \
+                    settings.MONGODB_TLS_CERT_KEY_FILE
+            if settings.MONGODB_TLS_CERT_KEY_FILE_PASSWORD:
+                options['tlsCertificateKeyFilePassword'] = \
+                    settings.MONGODB_TLS_CERT_KEY_FILE_PASSWORD
+            if settings.MONGODB_TLS_CRL_FILE:
+                options['tlsCRLFile'] = settings.MONGODB_TLS_CRL_FILE
+            if settings.MONGODB_TLS_ALLOW_INVALID_CERT:
+                options['tlsAllowInvalidCertificates'] = \
+                    settings.MONGODB_TLS_ALLOW_INVALID_CERT
+            if settings.MONGODB_TLS_ALLOW_INVALID_HOSTNAME:
+                options['tlsAllowInvalidHostnames'] = \
+                    settings.MONGODB_TLS_ALLOW_INVALID_HOSTNAME
+            if settings.MONGODB_TLS_CERTIFICATE_SELECTOR:
+                options['tlsCertificateSelector'] = \
+                    settings.MONGODB_TLS_CERTIFICATE_SELECTOR
         try:
             client = pymongo.MongoClient(uri, **options)
             if connect:
