@@ -432,6 +432,88 @@ class MongoGeoPointProperty(object):
         return getattr(self.__field, name)
 
 
+class MongoSubObjectProperty(object):
+    """Computed attributes based on zope.schema.Object
+
+    The field property will convert the gonve data to an object using the
+    given converter method or class. If None data is ginve for this field,
+    the field property does not create and add an object.
+
+    The field property get method will create a new object if None is stored
+    and a factor class or method is given.
+
+    Note: the MongoSubObjectProperty will store the object in the instance
+    using this property and the MongoOjectProperty will store object in another
+    collection.
+
+    """
+
+    def __init__(self, field, converter, factory=None, name=None):
+        if name is None:
+            name = field.__name__
+        self.__field = field
+        self.__converter = converter
+        self.__factory = factory
+        self.__name = name
+        self.__required = field.required
+        if field.readonly:
+            raise TypeError("Can't use readonly fields")
+        # preconditions
+        if not isinstance(field, zope.schema.Object):
+            raise TypeError(
+                "Use zope.schema.Object for GeoLocation field %s" % self.__name)
+
+    def __get__(self, inst, klass):
+        if inst is None:
+            return self
+        obj = inst.__dict__.get(self.__name)
+        if obj is None:
+            field = self.__field.bind(inst)
+            obj = getattr(field, 'default', None)
+        if obj is None and self.__factory is not None:
+            obj = self.__factory({
+                '__name__': self.__name,
+                '__parent___': inst,
+                })
+            inst.__dict__[self.__name] = obj
+        return obj
+
+    def __set__(self, inst, data):
+        # convert the value if a converter is given
+        if data is None:
+            # convert None value to empty dict
+            data = {}
+        if isinstance(data, dict):
+            # data given from mongo as bson otherwise we will add an object
+            data['__name__'] = self.__name
+            data['__parent__'] = inst
+            obj = self.__converter(data)
+        else:
+            obj = data
+            if obj.__parent__ is None:
+                obj.__parent__ = inst
+            elif obj.__parent__ is not inst:
+                raise ValueError(
+                    "Wrong __parent__ given, __parent__ must be %r" % inst,
+                    obj.__parent__)
+            # set __name__ if not given
+            if obj.__name__ is None:
+                obj.__name__ = unicode(self.__name)
+        # validate the obj
+        field = self.__field.bind(inst)
+        field.validate(obj)
+        if field.readonly and inst.__dict__.has_key(self.__name):
+            raise ValueError(self.__name, 'field is readonly')
+        # apply changed obj
+        inst.__dict__[self.__name] = obj
+        if inst._m_initialized:
+            # mark as changed, but only if instance is initialized
+            inst._m_changed = True
+
+    def __getattr__(self, name):
+        return getattr(self.__field, name)
+
+
 class MongoObjectProperty(object):
     """Computed MongoObject based on schema fields and given configuration
     using an unique _moid attribute as __parent__ reference and an attribute
