@@ -34,8 +34,8 @@ class IMongoList(zope.schema.interfaces.IList):
     """
 
 
-class IMongoSubObjectConverter(zope.schema.interfaces.IObject):
-    """Mongo object converter field"""
+# class IMongoSubObjectConverter(zope.schema.interfaces.IObject):
+#     """Mongo object converter field"""
 
 
 class IMongoBinary(zope.schema.interfaces.IBytes):
@@ -448,7 +448,7 @@ class IMongoItem(ISetup, IConvert, IDump, ICreatedModified):
         marker for track file system references in m01.mongofs.
         """
 
-class IMongoSubObject(ISetup, IConvert, IDump, ICreatedModified):
+class IMongoSubObject(ISetup, IConvert, IDump):
     """Mongo item base class.
 
     Note: only MongoFieldProperty attributes get observed and updated by our
@@ -478,12 +478,6 @@ class IMongoSubObject(ISetup, IConvert, IDump, ICreatedModified):
         default=None,
         required=True)
 
-    _version = zope.schema.Int(
-        title=u'Version',
-        description=u'Mongo item version',
-        default=0,
-        required=True)
-
 
 class IMongoStorageItem(IMongoItem):
     """Mongo storage item."""
